--[[
	Copyright (c) 2012 Kevin Sacro

	Permission is hereby granted, free of charge, to any person obtaining a
	copy of this software and associated documentation files (the "Software"),
	to deal in the Software without restriction, including without limitation
	the rights to use, copy, modify, merge, publish, distribute, sublicense,
	and/or sell copies of the Software, and to permit persons to whom the
	Software is furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included
	in all copies or substantial portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	USE OR OTHER DEALINGS IN THE SOFTWARE.
--]]

-- Convenience table for defining/playing audio sources.

local audio = {}

audio.enabled = true

-- defines audio sources to be used in the game
-- and some convenience methods for playing those
-- audio sources
local sound = {}

function audio.add(path,playback,id)
	sound[id] = love.audio.newSource(path,playback)
	return sound[id]
end

function audio.play(id)
	if audio.enabled then
		sound[id]:stop()
		sound[id]:setLooping(false)
		sound[id]:play()
	end
end

function audio.loop(id)
	if audio.enabled then
		sound[id]:setLooping(true)
		sound[id]:play()
	end
end

function audio.stop(id)
	if audio.enabled then
		sound[id]:stop()
	end
end

function audio.stopAll()
	if audio.enabled then
		for _, v in pairs(sound) do
			v:stop()
		end
	end
end

function audio.get(id)
	return sound[id]
end

return audio