
-- [Ice Project 2012, turtlesort.com]

-- For displaying the credits after player
-- finishes game! The credits are stored in
-- gametext.lua.

local scene = {}
local credits = game.text.credits
local credit_duration
local fade_duration
local x_align
local y_align

local credit_timer
local credit_index
local loaded

function scene.init()
	credit_duration = 5.0 -- seconds per credit
	fade_duration = 0.75
	x_align = 200
	y_align = 220

	credit_timer = 0
	credit_index = 1
	loaded = false
end

function scene.load()

	if not loaded then
		loaded = true

		if not game.snow.on then
			game.snow.clear()
			game.snow.fillscreen()
			game.snow.on = true
		end

		game.audio.stopAll()
		game.audio.play('theme')

		g.setBackgroundColor(0,0,0)
	end
	
end

function scene.update(dt)
	game.snow.update(dt)
	
	credit_timer = credit_timer + dt
	if credit_timer > credit_duration then
		credit_timer = 0
		credit_index = credit_index + 1
		
		if credit_index > #credits then
			credit_index = #credits
		end
		
	end
end

function scene.draw()

	game.snow.draw()

	local c1 = credits[credit_index]
	local alpha = math.floor(255 * ((credit_timer - (credit_duration - fade_duration)) / fade_duration))
	
	--if alpha > 255 then alpha = 255 end
	if alpha < 0 or (credit_index == #credits) then alpha = 0 end
	
	-- current credit fades out
	g.setColor(255,255,255,255-alpha)
	g.setFont(game.font.get(22))
	g.printf(c1[1], 15, y_align, g.getWidth(), 'center')

	g.setFont(game.font.get(30))
	g.printf(c1[2], 15, y_align + 50, g.getWidth(), 'center')
	
	-- next credit fades in 
	--
	if alpha > 0 and not (credit_index == #credits) then		
		local c2 = credits[credit_index+1]
		g.setColor(255,255,255,alpha)
		g.setFont(game.font.get(22))
		g.printf(c2[1], 15, y_align, g.getWidth(), 'center')
	
		g.setFont(game.font.get(30))
		g.printf(c2[2], 15, y_align + 50, g.getWidth(), 'center')
	end
	--]]
end

function scene.keypressed(key,unicode)

	if key == 'escape' then
		love.event.quit()
	elseif key == ' ' and credit_index == #credits then
		game.audio.stopAll()
		game.getScene('intro').init()
		game.getScene('main').init()
		game.getScene('falling').init()
		-- game.getScene('language').init()
		game.getScene('fader').init()
		game.getScene('ending').init()
		game.setCurrentScene('intro')

	end

end

return scene